@@ -1,7 +1,9 @@
 package Software::Catalog::SW::filezilla;
 
-our $DATE = '2019-10-26'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-10-02'; # DATE
+our $DIST = 'Software-Catalog-SW-filezilla'; # DIST
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -13,19 +15,20 @@ with 'Software::Catalog::Role::Software';
 
 use Software::Catalog::Util qw(extract_from_url);
 
-sub summary { "Cross-platform GUI FTP/SFTP client" }
-
-sub homepage_url { "https://filezilla-project.org" }
-
-sub latest_version {
+sub archive_info {
     my ($self, %args) = @_;
-
-    extract_from_url(
-        url => "https://filezilla-project.org/download.php?platform=" . $self->_canon2native_arch($args{arch}),
-        re  => qr! <a id="quickdownloadbuttonlink" href="[^"]+/FileZilla_(\d+(?:\.\d+)*)!,
-    );
+    [200, "OK", {
+        programs => [
+            {name=>"filezilla", path=>"/bin"},
+            # XXX fzputtygen
+            # XXX fzsftp
+            # XXX fzstorj
+        ],
+    }];
 }
 
+sub available_versions { [501, "Not implemented"] }
+
 sub canon2native_arch_map {
     return +{
         'linux-x86_64' => 'linux',
@@ -44,18 +47,21 @@ sub download_url {
     );
 }
 
-sub archive_info {
+sub homepage_url { "https://filezilla-project.org" }
+
+sub is_dedicated_profile { 0 }
+
+sub latest_version {
     my ($self, %args) = @_;
-    [200, "OK", {
-        programs => [
-            {name=>"filezilla", path=>"/bin"},
-            # XXX fzputtygen
-            # XXX fzsftp
-            # XXX fzstorj
-        ],
-    }];
+
+    extract_from_url(
+        url => "https://filezilla-project.org/download.php?platform=" . $self->_canon2native_arch($args{arch}),
+        re  => qr! <a id="quickdownloadbuttonlink" href="[^"]+/FileZilla_(\d+(?:\.\d+)*)!,
+    );
 }
 
+sub release_note { [501, "Not implemented"] }
+
 1;
 # ABSTRACT: FileZilla
 
@@ -71,7 +77,7 @@ Software::Catalog::SW::filezilla - FileZilla
 
 =head1 VERSION
 
-This document describes version 0.002 of Software::Catalog::SW::filezilla (from Perl distribution Software-Catalog-SW-filezilla), released on 2019-10-26.
+This document describes version 0.003 of Software::Catalog::SW::filezilla (from Perl distribution Software-Catalog-SW-filezilla), released on 2020-10-02.
 
 =for Pod::Coverage ^(.+)$
 
@@ -97,7 +103,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
